@@ -31,4 +31,7 @@ get_stat_info(lm_pid_t pid, lm_pid_t *ppid_out, lm_time_t *start_time_out);
 lm_size_t
 get_process_path(lm_pid_t pid, lm_char_t *pathbuf, size_t pathsize);
 
+lm_char_t **
+get_process_cmdline(lm_pid_t pid);
+
 #endif
